@@ -1,3 +1,6 @@
+DEFAULT = 'www'
+
+INITIALIZATION_MESSAGE = '\n-------------- Initializing `ONCE` Func(s) --------------'
 
 METHOD_CONNECT = CONNECT = 'CONNECT'
 METHOD_DELETE = DELETE = 'DELETE'
@@ -8,6 +11,7 @@ METHOD_PATCH = PATCH = 'PATCH'
 METHOD_POST = POST = 'POST'
 METHOD_PUT = PUT = 'PUT'
 METHOD_TRACE = TRACE = 'TRACE'
+METHODS = [GET, HEAD, POST, PUT, PATCH, CONNECT, TRACE, DELETE, OPTIONS]
 
 MESSAGE_NOT_FOUND = 'Not found'
 
